# EduTK: a toolkit in *Python* to create modern exercises for programming tutorials

[![Version](https://img.shields.io/pypi/v/edutk?color=90b4ed&label=latest)](https://pypi.org/project/edutk/) [![Download stats](https://img.shields.io/pypi/dm/edutk.svg)](https://pypistats.org/packages/edutk) [![Stars](https://img.shields.io/github/stars/epeios-q37/edutk-python.svg?style=social)](https://github.com/epeios-q37/edutk-python)[![license: MIT](https://img.shields.io/github/license/epeios-q37/edutk-python)](https://github.com/epeios-q37/edutk-python/blob/master/LICENSE)

Toolkit with some facilities to make exercises for programming tutorials. It's based on the [*Atlas* toolkit](https://q37.info/s/c7hfkzvs).

See [this repository](https://q37.info/s/tpkx4cfk) for an example of use.
